@@ -110,15 +110,14 @@ void init_buttonbindings(void)
 	feh_set_bb(&buttons.rotate, 4, 2);
 
 	home = getenv("HOME");
-	if (!home)
-		eprintf("No HOME in environment");
-
 	confhome = getenv("XDG_CONFIG_HOME");
 
 	if (confhome)
 		confpath = estrjoin("/", confhome, "feh/buttons", NULL);
-	else
+	else if (home)
 		confpath = estrjoin("/", home, ".config/feh/buttons", NULL);
+	else
+		return;
 
 	conf = fopen(confpath, "r");
 
@@ -379,10 +378,13 @@ static void feh_event_handle_ButtonRelease(XEvent * ev)
 				y /= winwid->zoom;
 				thumbfile = feh_thumbnail_get_file_from_coords(x, y);
 				if (thumbfile) {
-					if (opt.actions[0])
+					if (opt.actions[0]) {
 						feh_action_run(thumbfile, opt.actions[0]);
-					else
+						if (!opt.hold_actions[0])
+							feh_thumbnail_mark_removed(thumbfile, 0);
+					} else {
 						feh_thumbnail_show_fullsize(thumbfile);
+					}
 				}
 			}
 		} else {
