@@ -89,21 +89,33 @@ void real_loadables_mode(int loadable)
 		if (feh_load_image(&im, file)) {
 			/* loaded ok */
 			if (loadable) {
+				if (opt.verbose)
+					feh_display_status('.');
 				puts(file->filename);
 				feh_action_run(file, opt.actions[0]);
 			}
-			else
+			else {
+				if (opt.verbose)
+					feh_display_status('s');
 				ret = 1;
+			}
 			gib_imlib_free_image_and_decache(im);
 		} else {
 			/* Oh dear. */
 			if (!loadable) {
+				if (opt.verbose)
+					feh_display_status('.');
 				puts(file->filename);
 				feh_action_run(file, opt.actions[0]);
 			}
-			else
+			else {
+				if (opt.verbose)
+					feh_display_status('s');
 				ret = 1;
+			}
 		}
 	}
+	if (opt.verbose)
+		feh_display_status(0);
 	exit(ret);
 }
