@@ -30,6 +30,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "timers.h"
 #include "options.h"
 #include "events.h"
+#include "signals.h"
 #include "wallpaper.h"
 
 char **cmdargv = NULL;
@@ -40,6 +41,7 @@ int main(int argc, char **argv)
 {
 	atexit(feh_clean_exit);
 
+	setup_signal_handlers();
 	init_parse_options(argc, argv);
 
 	init_imlib_fonts();
