@@ -70,6 +70,7 @@ void init_parse_options(int argc, char **argv)
 #ifdef HAVE_LIBXINERAMA
 	/* if we're using xinerama, then enable it by default */
 	opt.xinerama = 1;
+	opt.xinerama_index = -1;
 #endif				/* HAVE_LIBXINERAMA */
 
 	feh_getopt_theme(argc, argv);
@@ -132,15 +133,16 @@ static void feh_load_options_for_theme(char *theme)
 	int cont = 0;
 	int bspos;
 
-	if (!home)
-		eprintf("You have no HOME, cannot read themes");
-
-	oldrcpath = estrjoin("/", home, ".fehrc", NULL);
-
 	if (confbase)
 		rcpath = estrjoin("/", confbase, "feh/themes", NULL);
-	else
+	else if (home)
 		rcpath = estrjoin("/", home, ".config/feh/themes", NULL);
+	else {
+		weprintf("You have no HOME, cannot read configuration");
+		return;
+	}
+
+	oldrcpath = estrjoin("/", home, ".fehrc", NULL);
 
 	fp = fopen(rcpath, "r");
 
@@ -235,7 +237,7 @@ static void feh_parse_options_from_string(char *opts)
 
 			list[num - 1] = feh_string_normalize(s);
 			break;
-		} else if (*t == '\"' && last != '\\')
+		} else if (((*t == '\"') || (*t == '\'')) && last != '\\')
 			inquote = !(inquote);
 		last = *t;
 	}
@@ -264,6 +266,9 @@ char *feh_string_normalize(char *str)
 		else if ((*s == '\"') && (last == '\\'))
 			ret[i++] = '\"';
 		else if ((*s == '\"') && (last == 0));
+		else if ((*s == '\'') && (last == '\\'))
+			ret[i++] = '\'';
+		else if ((*s == '\'') && (last == 0));
 		else if ((*s == ' ') && (last == '\\'))
 			ret[i++] = ' ';
 		else
@@ -271,7 +276,7 @@ char *feh_string_normalize(char *str)
 
 		last = *s;
 	}
-	if (i && (ret[i - 1] == '\"'))
+	if (i && ((ret[i - 1] == '\"') || (ret[i - 1] == '\'')))
 		ret[i - 1] = '\0';
 	else
 		ret[i] = '\0';
@@ -400,6 +405,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"no-fehbg"      , 0, 0, 236},
 		{"keep-zoom-vp"  , 0, 0, 237},
 		{"scroll-step"   , 1, 0, 238},
+		{"xinerama-index", 1, 0, 239},
 
 		{0, 0, 0, 0}
 	};
@@ -420,6 +426,10 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			break;
 		case '<':
 			XParseGeometry(optarg, &discard, &discard, &opt.max_width, &opt.max_height);
+			if (opt.max_width == 0)
+				opt.max_width = UINT_MAX;
+			if (opt.max_height == 0)
+				opt.max_height = UINT_MAX;
 			break;
 		case '>':
 			XParseGeometry(optarg, &discard, &discard, &opt.min_width, &opt.min_height);
@@ -520,6 +530,11 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 						"sort by filename", optarg);
 				opt.sort = SORT_FILENAME;
 			}
+			if (opt.randomize) {
+				weprintf("commandline contains --randomize and --sort. "
+						"--randomize has been unset");
+				opt.randomize = 0;
+			}
 			break;
 		case 'T':
 			theme = estrdup(optarg);
@@ -634,6 +649,11 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			break;
 		case 'z':
 			opt.randomize = 1;
+			if (opt.sort != SORT_NONE) {
+				weprintf("commandline contains --sort and --randomize. "
+						"--sort has been unset");
+				opt.sort = SORT_NONE;
+			}
 			break;
 		case '|':
 			opt.start_list_at = estrdup(optarg);
@@ -736,6 +756,9 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		case 238:
 			opt.scroll_step = atoi(optarg);
 			break;
+		case 239:
+			opt.xinerama_index = atoi(optarg);
+			break;
 		default:
 			break;
 		}
@@ -783,12 +806,6 @@ static void check_options(void)
 		eprintf("You cannot combine --list with other modes");
 	}
 
-	if (opt.sort && opt.randomize) {
-		weprintf("You cant sort AND randomize the filelist...\n"
-				"randomize mode has been unset\n");
-		opt.randomize = 0;
-	}
-
 	if (opt.loadables && opt.unloadables) {
 		eprintf("You cannot combine --loadable with --unloadable");
 	}
