@@ -357,7 +357,7 @@ void init_thumbnail_mode(void)
 		winwidget_render_image(winwid, 0, 1);
 
 	if (opt.verbose)
-		putc('\n', stdout);
+		putc('\n', stderr);
 
 	if (opt.title_font) {
 		int fw, fh, fx, fy;
@@ -382,7 +382,7 @@ void init_thumbnail_mode(void)
 			snprintf(output_buf, 1024, "%s/%s", opt.output_dir, opt.output_file);
 		else
 			strncpy(output_buf, opt.output_file, 1024);
-		ungib_imlib_save_image_with_error_return(td.im_main, output_buf, &err);
+		gib_imlib_save_image_with_error_return(td.im_main, output_buf, &err);
 		if (err) {
 			feh_imlib_print_load_error(output_buf, td.im_main, err);
 		}
@@ -391,8 +391,8 @@ void init_thumbnail_mode(void)
 
 			tw = gib_imlib_image_get_width(td.im_main);
 			th = gib_imlib_image_get_height(td.im_main);
-			fprintf(stdout, PACKAGE " - File saved as %s\n", output_buf);
-			fprintf(stdout,
+			fprintf(stderr, PACKAGE " - File saved as %s\n", output_buf);
+			fprintf(stderr,
 					"    - Image is %dx%d pixels and contains %d thumbnails\n",
 					tw, th, thumbnailcount);
 		}
